==> urjtag-0.7.tar.bz2: urjtag-0.7/src/cmd/bus.c <==
/*
 * $Id: bus.c 523 2003-08-19 08:42:21Z telka $
 *
 * Copyright (C) 2003 ETC s.r.o.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 * 02111-1307, USA.
 *
 * Written by Marcel Telka <marcel@telka.sk>, 2003.
 *
 */

#include "sysdep.h"

#include <stdio.h>
#include <string.h>

#include "jtag.h"

#include "cmd.h"

static int
cmd_bus_run( char *params[] )
{
	unsigned int n;

	if (cmd_params( params ) != 2)
		return -1;

	if (!cmd_test_cable())
		return 1;

	if (!chain->parts) {
		printf( _("Run \"detect\" first.\n") );
		return 1;
	}

	if (cmd_get_number( params[1], &n ))
		return -1;

	if (n >= buses.len) {
		printf( _("%s: invalid bus number\n"), "bus" );
		return 1;
	}

	bus = buses.buses[n];

	return 1;
}

static void
cmd_bus_help( void )
{
	printf( _(
		"Usage: %s BUS\n"
		"Change active bus.\n"
		"\n"
		"BUS           bus number\n"
	), "bus" );
}

cmd_t cmd_bus = {
	"bus",
	N_("change active bus"),
	cmd_bus_help,
	cmd_bus_run
};

==> urjtag-0.9.tar.bz2: urjtag-0.9/src/cmd/bus.c <==
/*
 * $Id: bus.c 1102 2008-02-27 03:38:31Z jiez $
 *
 * Copyright (C) 2003 ETC s.r.o.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 * 02111-1307, USA.
 *
 * Written by Marcel Telka <marcel@telka.sk>, 2003.
 *
 */

#include "sysdep.h"

#include <stdio.h>
#include <string.h>

#include "jtag.h"

#include "cmd.h"

static int
cmd_bus_run( chain_t *chain, char *params[] )
{
	unsigned int n;

	if (cmd_params( params ) != 2)
		return -1;

	if (!cmd_test_cable( chain ))
		return 1;

	if (!chain->parts) {
		printf( _("Run \"detect\" first.\n") );
		return 1;
	}

	if (cmd_get_number( params[1], &n ))
		return -1;

	if (n >= buses.len) {
		printf( _("%s: invalid bus number\n"), "bus" );
		return 1;
	}

	bus = buses.buses[n];

	return 1;
}

static void
cmd_bus_help( void )
{
	printf( _(
		"Usage: %s BUS\n"
		"Change active bus.\n"
		"\n"
		"BUS           bus number\n"
	), "bus" );
}

cmd_t cmd_bus = {
	"bus",
	N_("change active bus"),
	cmd_bus_help,
	cmd_bus_run
};
